@@ -10,8 +10,8 @@
 
 #include <kconfigwidgets_export.h>
 
-#ifndef KCONFIGWIDGETS_NO_KAUTH
-#include <KAuthAction>
+#if KCONFIGWIDGETS_WITH_KAUTH
+#include <KAuth/Action>
 #endif
 
 #include <QVariant>
@@ -128,7 +128,9 @@ public:
     /**
      * Return a quick-help text.
      *
-     * This method is called when the module is docked.
+     * This method may be called when the module is docked. The quick help would generally
+     * be used as "what's this" text if the view container supports the "what's this"
+     * system.
      * The quick-help text should contain a short description of the module and
      * links to the module's help files. You can use QML formatting tags in the text.
      *
@@ -136,14 +138,18 @@ public:
      */
     virtual QString quickHelp() const;
 
+#if KCONFIGWIDGETS_BUILD_DEPRECATED_SINCE(5, 90)
     /**
      * This is generally only called for the KBugReport.
      * If you override you should  have it return a pointer to a constant.
      *
      *
      * @returns the KAboutData for this module
+     * @deprecated since 5.90. Use the KPluginMetaData the KCModule was instantiated from.
      */
+    KCONFIGWIDGETS_DEPRECATED_VERSION(5, 90, "Use the KPluginMetaData the KCModule was instantiated from")
     virtual const KAboutData *aboutData() const;
+#endif
 
     /**
      * This sets the KAboutData returned by aboutData()
@@ -187,7 +193,13 @@ public:
      */
     bool useRootOnlyMessage() const;
 
+#if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(5, 90)
+    /**
+     * @deprecated since 5.90. Use the KPluginMetaData the KCModule was instantiated from.
+     */
+    KCONFIGWIDGETS_DEPRECATED_VERSION(5, 90, "Use the KPluginMetaData the KCModule was instantiated from")
     KAboutData componentData() const;
+#endif
 
     /**
      * @return a list of @ref KConfigDialogManager's in use, if any.
@@ -227,7 +239,7 @@ public:
      */
     bool defaultsIndicatorsVisible() const;
 
-#ifndef KCONFIGWIDGETS_NO_KAUTH
+#if KCONFIGWIDGETS_WITH_KAUTH
     /**
      * @brief Set if the module's save() method requires authorization to be executed
      *
@@ -336,6 +348,10 @@ protected:
     KConfigDialogManager *addConfig(KCoreConfigSkeleton *config, QWidget *widget);
 
 #if KCONFIGWIDGETS_ENABLE_DEPRECATED_SINCE(5, 84)
+    // No deprecation warning by compiler here, as the replacement will be
+    // automatically picked by the compiler in the future, being the method
+    // overload using the base-class of the argument type.
+    // Avoids the need to do extra-casting right now on the caller side.
     /**
      * Adds a KConfigskeleton @p config to watch the widget @p widget
      *
@@ -346,7 +362,6 @@ protected:
      * @param widget the widget to watch
      * @deprecated since 5.84, use addConfig(KCoreConfigSkeleton *config, QWidget *widget);
      */
-    KCONFIGWIDGETS_DEPRECATED_VERSION(5, 84, "Use KConfigDialogManager *addConfig(KCoreConfigSkeleton *config, QWidget *widget);")
     KConfigDialogManager *addConfig(KConfigSkeleton *config, QWidget *widget);
 #endif
 
@@ -431,7 +446,7 @@ protected Q_SLOTS:
      */
     void widgetChanged();
 
-#ifndef KCONFIGWIDGETS_NO_KAUTH
+#if KCONFIGWIDGETS_WITH_KAUTH
     /**
      * The status of the auth action, if one, has changed
      */
